@@ -1,6 +1,8 @@
 """ Various utilties """
 
 import re
+from operator import itemgetter
+import six
 
 encode_replacements = {
     '"': '&dquot;',
@@ -21,12 +23,12 @@ def encode_task(task):
     # First, clean the task:
     task = task.copy()
     for k in task:
-        for unsafe, safe in encode_replacements.iteritems():
+        for unsafe, safe in six.iteritems(encode_replacements):
             task[k] = task[k].replace(unsafe, safe)
 
     # Then, format it as a string
     return "[%s]\n" % " ".join([
-        "%s:\"%s\"" % (k, v) for k, v in task.iteritems()
+        "%s:\"%s\"" % (k, v) for k, v in sorted(task.items(), key=itemgetter(0))
     ])
 
 
@@ -44,7 +46,7 @@ def decode_task(line):
     task = {}
     for key, value in re.findall(r'(\w+):"(.*?)"', line):
         task[key] = value
-        for unsafe, safe in decode_replacements.iteritems():
+        for unsafe, safe in six.iteritems(decode_replacements):
             task[key] = task[key].replace(unsafe, safe)
 
     return task
